import { system, world } from '@minecraft/server';
import { getPlayerTagData, getTagValue } from '../../systemFiles/tagUtils.js';
import {runcmd,runcmd_at, BoolToNum, getScore } from '../../systemFiles/tools';

const weaponTags = [
    { tag: "cs:m22", name: "M22", ammo: 18 },
    { tag: "cs:mn5", name: "MN5", ammo: 8 },
    { tag: "cs:rpk37", name: "RPK37", ammo: 30 },
    { tag: "cs:pp42", name: "PP42", ammo: 30 },
    { tag: "cs:rvl34", name: "RVL34", ammo: 9 },
    { tag: "cs:g53", name: "G53", ammo: 20 },
    { tag: "cs:acw", name: "ACW", ammo: 30 },
    { tag: "cs:ak37", name: "AK37", ammo: 30 },
    { tag: "cs:vec35", name: "VEC35", ammo: 35 },
    { tag: "cs:m42", name: "M42", ammo: 30 },
    { tag: "cs:mdxr", name: "MDXR", ammo: 30 },
    { tag: "cs:dbn", name: "DBN", ammo: 2 }
];

const grenadeTags = [
    { tag: "cs:title_he_grenade", name: "item.addon:he_grenade" },
    { tag: "cs:title_smoke_grenade", name: "item.addon:smoke_grenade" },
    { tag: "cs:title_flash_grenade", name: "item.addon:flash_grenade" },
    { tag: "cs:title_fire_grenade", name: "item.addon:fire_grenade" }
];

function updateWeaponInfo(entity) {
    for (let weapon of weaponTags) {
        if (entity.hasTag(weapon.tag)) {
            // Обрабатываем исключение для cs:g53
            let scoreTag = (weapon.tag === "cs:g53") ? "glock53" : weapon.tag.replace("cs:", "");
            let score = world.scoreboard.getObjective(scoreTag)?.getScore(entity) ?? 0;
            return {
                gunText: `,{"text":"§7\n\n"},{"translate":"howtoplay.weapons"},{"text":":§r ${weapon.name}"}`,
                scoreText: `,{"text":"\n§7"},{"translate":"fearcube.cs.cartridges"},{"text":":§r ${score}/${weapon.ammo} "}`
            };
        }
    }
    return { gunText: "", scoreText: "" };
}



function updateKnifeInfo(entity) {
    if (entity.hasTag("cs:knite")) {
        return {
            gunText: `,{"text":"§7\n\n"},{"translate":"howtoplay.weapons"},{"text":":§r \n"},{"translate":"item.addon:combat_knife"}`,
            scoreText: ""
        };
    }
    return { gunText: "", scoreText: "" };
}

function updateGrenadeInfo(entity) {
    for (let grenade of grenadeTags) {
        if (entity.hasTag(grenade.tag)) {
            return {
                gunText: `,{"text":"§7\n\n"},{"translate":"howtoplay.weapons"},{"text":":§r \n"},{"translate":"${grenade.name}"}`,
                scoreText: ""
            };
        }
    }
    return { gunText: "", scoreText: "" };
}

system.afterEvents.scriptEventReceive.subscribe(async (event) => {
    if (event.id === "fearcube:ui" && event.message === "cs_main") {
        const entity = event.sourceEntity;
        let track_viewer = getScore("cs:operations","track_viewer");
        let viewer = "";


        if (track_viewer > 0) {
            viewer = `,{"text":"  §a${track_viewer}"}`;
        }

        if (entity) {
            let text = "fearcube.not.found";
            let gunReload = "";
            let bombPlant = "";
            let webSite = `,{"text":"\n\n§b "},{"translate":"fearcube.website"}`;
            let teamInfo = `,{"text":"§r\n\n§b"},{"translate":"fearcube.cs.commando"},{"text":"§r | §c"},{"translate":"fearcube.cs.terrorist"},{"text":"§r"}`;
            let gameInfo = `,{"text":"§r\n§7"},{"translate":"deathScreen.score"},{"text":":§b "}, {"score":{"name":"gameScoreCommando","objective":"cs:operations"}}, {"text":"§r | §c"}, {"score":{"name":"gameScoreTerrorist","objective":"cs:operations"}},   {"text":"§r"}`;  
            let gameTimer = "";
            let gameBalance = "";
            let shoop_main = "";


            let { gunText, scoreText } = updateWeaponInfo(entity);
            if (!gunText) {
                // Если нет оружия, проверяем боевой нож
                let knifeInfo = updateKnifeInfo(entity);
                gunText = knifeInfo.gunText;
                scoreText = knifeInfo.scoreText;
            }
            if (!gunText) {
                // Если нет ножа, проверяем гранаты
                let grenadeInfo = updateGrenadeInfo(entity);
                gunText = grenadeInfo.gunText;
                scoreText = grenadeInfo.scoreText;
            }





            if (entity.hasTag("cs:bomb_plant")) {
                bombPlant = `,{"text":"§c\n "},{"translate":"fearcube.cs.bomb_planted"} ,{"text":"§r"}`;

            } if (entity.hasTag("cs:gun_reload")) {
                gunReload = `,{"text":"\n\n§c"},{"translate":"fearcube.cs.gun_reload"} ,{"text":"§r"}`;
                scoreText = ""
                gunText = ""

            } if (entity.hasTag("cs:balance")) {
                gameBalance = `,{"text":"§r\n§7"},{"translate":"fearcube.balance"},{"text":":§a "}, {"score":{"name":"@s","objective":"cs:balance"}},   {"text":"$§r"}`
                let shoop = getScore("cs:operations", "timer_for_purchasing1");
                let shoop1 = getScore("fear:settings", "cs.store_validity_time");
                let interval = shoop1 / 8;
                let step = Math.floor(shoop / interval) + 1;
            
                // Выводим текст для текущего шага
                // no sapper kit        
                switch (step) {
                    case 1:
                        shoop_main = `,{"text":"§r\n\n§7 "},{"translate":"item.fear:cs_shoop"}`
                        break;
                    case 2:
                        shoop_main = `,{"text":"§r\n\n§7 "},{"translate":"item.fear:cs_shoop"}`
                        break;
                    case 3:
                        shoop_main = `,{"text":"§r\n\n§7 "},{"translate":"item.fear:cs_shoop"}`
                        break;
                    case 4:
                        shoop_main = `,{"text":"§r\n\n§7 "},{"translate":"item.fear:cs_shoop"}`
                        break;
                    case 5:
                        shoop_main = `,{"text":"§r\n\n§7 "},{"translate":"item.fear:cs_shoop"}`
                        break;
                    case 6:
                        shoop_main = `,{"text":"§r\n\n§7 "},{"translate":"item.fear:cs_shoop"}`
                        break;
                    case 7:
                        shoop_main = `,{"text":"§r\n\n§7 "},{"translate":"item.fear:cs_shoop"}`
                        break;
                    case 8:
                        shoop_main = `,{"text":"§r\n\n§7 "},{"translate":"item.fear:cs_shoop"}`
                        break;
                    default:
                        break;
                }


            } if (entity.hasTag("cs:timer_purchasing")) {
            let participant = getScore("cs:operations","timer_for_purchasing");
            let roundedValue = Math.round(participant / 20);
            let minutes = Math.floor(roundedValue / 60);
            let seconds = roundedValue % 60;
            let formattedSeconds = seconds < 10 ? '0' + seconds : seconds;
            gameTimer = `,{"text":"\n\n§7"},{"translate":"fearcube.timer"},{"text":":§r ${minutes}:${formattedSeconds}"}`;

            
            } if (entity.hasTag("cs:timer_until_bomb_planted")) { 
            let participant = getScore("cs:operations","timer_until_bomb_planted");
            let roundedValue = Math.round(participant / 20);
            let minutes = Math.floor(roundedValue / 60);
            let seconds = roundedValue % 60;
            let formattedSeconds = seconds < 10 ? '0' + seconds : seconds;
            gameTimer = `,{"text":"\n\n§7"},{"translate":"fearcube.timer"},{"text":":§r ${minutes}:${formattedSeconds}"}`;
        
            } if (entity.hasTag("cs:timer_bomb_planted")) {   
            let participant = getScore("cs:operations","timer_until_explosion");
            let roundedValue = Math.round(participant / 20);
            let minutes = Math.floor(roundedValue / 60);
            let seconds = roundedValue % 60;
            let formattedSeconds = seconds < 10 ? '0' + seconds : seconds;
            gameTimer = `,{"text":"\n\n§7"},{"translate":"fearcube.timer"},{"text":":§c ${minutes}:${formattedSeconds}"}`;
            }






            const players = world.getPlayers();

            let commandoCount = 0;
            let terroristCount = 0;
            const commandoIcon = ``;
            const terroristIcon = ``;
            const maxPlayersPerRow = 15;
            let space =""
            
            players.forEach(player => {
                if (player.hasTag("cs:commando") && player.getGameMode() === "adventure" && !player.hasTag("cs:lobby")) { 
                    commandoCount++;
                }
                if (player.hasTag("cs:terrorist") && player.getGameMode() === "adventure" && !player.hasTag("cs:lobby")) { 
                    terroristCount++;
                }
            });


            if (commandoCount <= 1) { space = "     "}
            if (commandoCount === 2) { space = "    "}
            if (commandoCount === 3) { space = "  "}
            if (commandoCount === 4) { space = ""}
            
            const createRow = (count, icon) => {
                let row = '';
                for (let i = 0; i < count; i++) {
                    row += icon;
                    if ((i + 1) % maxPlayersPerRow === 0 && i !== count - 1) {
                        row += ' | ';
                    }
                }
                return row;
            };
            
            const commandoTable = createRow(commandoCount, commandoIcon);
            const terroristTable = createRow(terroristCount, terroristIcon);
            
            const rows = Math.max(Math.ceil(commandoCount / maxPlayersPerRow), Math.ceil(terroristCount / maxPlayersPerRow));
            
            let output = '';
            for (let i = 0; i < rows; i++) {
                let commandoRow = commandoTable.slice(i * maxPlayersPerRow, (i + 1) * maxPlayersPerRow).padEnd(maxPlayersPerRow, '');
                let terroristRow = terroristTable.slice(i * maxPlayersPerRow, (i + 1) * maxPlayersPerRow).padEnd(maxPlayersPerRow, '');
                output += '\n' + commandoRow + space + ' | ' + terroristRow;
            }
            
            
            

            entity.runCommandAsync(`titleraw @s title {"rawtext":[{"translate":"fearcube.cs.name1"} ${viewer}  ${teamInfo} ,{"text":"${output}"} ${gameInfo} ${gameTimer} ${bombPlant} ${gunText} ${scoreText} ${gunReload} ${shoop_main} ${gameBalance} ${webSite}]}`);
        }
    }
});



system.afterEvents.scriptEventReceive.subscribe(async (event) => {
    if (event.id === "fearcube:ui" && event.message === "cs_gun_reload") {
        const entity = event.sourceEntity;

        if (entity) {
        let m22 = `unless entity @s[hasitem={item=addon:m22_empty,location=slot.weapon.mainhand}] `;
        let mn5 = `unless entity @s[hasitem={item=addon:mn5_empty,location=slot.weapon.mainhand}] `;
        let rpk37 = `unless entity @s[hasitem={item=addon:rpk37_empty,location=slot.weapon.mainhand}] `;
        let rvl34 = `unless entity @s[hasitem={item=addon:rvl34_empty,location=slot.weapon.mainhand}] `;
        let g53 = `unless entity @s[hasitem={item=addon:glock53_empty,location=slot.weapon.mainhand}] `;
        let acw = `unless entity @s[hasitem={item=addon:acw_empty,location=slot.weapon.mainhand}] `;
        let ak37 = `unless entity @s[hasitem={item=addon:ak37_empty,location=slot.weapon.mainhand}] `;
        let vec35 = `unless entity @s[hasitem={item=addon:vec35_empty,location=slot.weapon.mainhand}] `;
        let m42 = `unless entity @s[hasitem={item=addon:m42_empty,location=slot.weapon.mainhand}] `;
        let dbn = `unless entity @s[hasitem={item=addon:dbn_empty,location=slot.weapon.mainhand}] `;
        let mdxr = `unless entity @s[hasitem={item=addon:mdxr_empty,location=slot.weapon.mainhand}] `;
        let pp42 = `unless entity @s[hasitem={item=addon:pp42_empty,location=slot.weapon.mainhand}] `;

        entity.runCommandAsync(`execute ${m22}${mn5}${rpk37}${rvl34}${g53}${acw}${ak37}${vec35}${m42}${dbn}${mdxr}${pp42}as @s at @s run tag @s remove cs:gun_reload`);
        }
    }
    if (event.id === "fearcube:ui" && event.message === "cs_info_round") {
        const entity = event.sourceEntity;
        let wins_in_rowT = getScore("cs:operations","wins_in_row.terrorist");
        let wins_in_rowС = getScore("cs:operations","wins_in_row.commando");
        let defeats_in_rowT = getScore("cs:operations","defeats_in_row.terrorist");
        let defeats_in_rowC = getScore("cs:operations","defeats_in_row.commando");


            // Вознаграждение Теров за серию поражений
        if (defeats_in_rowT === 1 ) { 
            entity.runCommandAsync(`execute as @s[tag=cs:terrorist] at @s run tellraw @s {"rawtext":[{"text":" +1400$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:terrorist] cs:balance 1400`);
        } else if (defeats_in_rowT === 2 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:terrorist] at @s run tellraw @s {"rawtext":[{"text":" +1900$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats_in_row"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:terrorist] cs:balance 1900`);
        } else if (defeats_in_rowT === 3 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:terrorist] at @s run tellraw @s {"rawtext":[{"text":" +2400$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats_in_row"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:terrorist] cs:balance 2400`);
        } else if (defeats_in_rowT === 4 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:terrorist] at @s run tellraw @s {"rawtext":[{"text":" +2900$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats_in_row"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:terrorist] cs:balance 2900`);
        } else if (defeats_in_rowT >= 5 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:terrorist] at @s run tellraw @s {"rawtext":[{"text":" +3400$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats_in_row"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:terrorist] cs:balance 3400`);
        }

        // Вознаграждение Спеца за серию поражений
        if (defeats_in_rowC === 1 ) { 
            entity.runCommandAsync(`execute as @s[tag=cs:commando] at @s run tellraw @s {"rawtext":[{"text":" +1400$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:commando] cs:balance 1400`);
        } else if (defeats_in_rowC === 2 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:commando] at @s run tellraw @s {"rawtext":[{"text":" +1900$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats_in_row"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:commando] cs:balance 1900`);
        } else if (defeats_in_rowC === 3 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:commando] at @s run tellraw @s {"rawtext":[{"text":" +2400$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats_in_row"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:commando] cs:balance 2400`);
        } else if (defeats_in_rowC === 4 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:commando] at @s run tellraw @s {"rawtext":[{"text":" +2900$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats_in_row"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:commando] cs:balance 2900`);
        } else if (defeats_in_rowC >= 5 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:commando] at @s run tellraw @s {"rawtext":[{"text":" +3400$"},{"text":"§2 "},{"translate":"fearcube.cs.defeats_in_row"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:commando] cs:balance 3400`);
        }


        if (wins_in_rowT >= 1 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:terrorist] at @s run tellraw @s {"rawtext":[{"text":" +3250$"},{"text":"§2 "},{"translate":"fearcube.cs.wins"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:terrorist] cs:balance 3250`);
        }
        if (wins_in_rowС >= 1 ) {
            entity.runCommandAsync(`execute as @s[tag=cs:commando] at @s run tellraw @s {"rawtext":[{"text":" +3250$"},{"text":"§2 "},{"translate":"fearcube.cs.wins"}]}`);
            entity.runCommandAsync(`scoreboard players add @s[tag=cs:commando] cs:balance 3250`);
        }


        // конец скрипта
        entity.runCommandAsync(`function games/cs/game/over_script`);
    }
    if (event.id === "fearcube:ui" && event.message === "cs_murder_show") {
        const entity = event.sourceEntity;
        const name = event.sourceEntity.name;
        // создание перемен
        let teamCommando = ``; let teamTerrorist = ``; let teamCommando1 = ``; let teamTerrorist1 = ``; let killGun = ``;
        let protection = "1";
        let money = "";
        let weapons = "fearcube.cs.kills_gun";
        
        // проверка в какой команде игрок
        if (entity.hasTag("cs:commando")) { teamCommando = `§9`;  }
        if (entity.hasTag("cs:terrorist")) {teamTerrorist = `§c`;  }

        const players = world.getPlayers(); // Получаем всех игроков на сервере
        players.forEach(player => {
            if (player.hasTag("cs:commando") && player.hasTag("cs:death")) { teamCommando1 = `§9` }
            if (player.hasTag("cs:terrorist") && player.hasTag("cs:death")) { teamTerrorist1 = `§c` }

            if (entity.hasTag("cs:commando") && player.hasTag("cs:commando") && player.hasTag("cs:death")) { protection = "2";}
            if (entity.hasTag("cs:terrorist") && player.hasTag("cs:terrorist") && player.hasTag("cs:death")) { protection = "2";}
        });

        

        // проверка держит ли игрок урожие
        if (entity.hasTag("cs:m22")) { 
            killGun = `(M22)` 
            money = "300";
        }
        if (entity.hasTag("cs:rvl34")) { 
            killGun = `(RVL34)` 
            money = "300";
        }
        if (entity.hasTag("cs:g53")) { 
            killGun = `(G53)` 
            money = "300";
         }
        if (entity.hasTag("cs:mn5")) { 
            killGun = `(MN5)`  
            money = "900";
        }
        if (entity.hasTag("cs:dbn")) { 
            killGun = `(DBN)`
            money = "900";
         }
        if (entity.hasTag("cs:vec35")) { 
            killGun = `(Vec35)`
            money = "300";
         }
        if (entity.hasTag("cs:acw")) { 
            killGun = `(ACW)`
            money = "300";
         }
        if (entity.hasTag("cs:pp42")) { 
            killGun = `(PP42)`
            money = "600";
         }
        if (entity.hasTag("cs:ak37")) { 
            killGun = `(AK37)` 
            money = "300";
        }
        if (entity.hasTag("cs:mdxr")) { 
            killGun = `(MDXR)`
            money = "300"; 
        }
        if (entity.hasTag("cs:m42")) { 
            killGun = `(M42)` 
            money = "300";

        }
        if (entity.hasTag("cs:rpk37")) { 
            killGun = `(RPK37)`
            money = "300";
         }
        if (entity.hasTag("cs:knite")) { 
            killGun = ``
            money = "1500";
            weapons = "fearcube.cs.kills_knite";
        }

        // Если нету тегов из списка выше то выполняется состояние default
        if (!entity.hasTag("cs:m22") && !entity.hasTag("cs:rvl34") && !entity.hasTag("cs:g53") && !entity.hasTag("cs:mn5") && !entity.hasTag("cs:dbn") && !entity.hasTag("cs:vec35")
         && !entity.hasTag("cs:acw") && !entity.hasTag("cs:ak37") && !entity.hasTag("cs:mdxr") && !entity.hasTag("cs:m42") && !entity.hasTag("cs:rpk37") && !entity.hasTag("cs:knite") && !entity.hasTag("cs:pp42")
        ) { killGun = `` ; money = "100"; }

        entity.runCommandAsync(`tellraw @a[tag=cs:game,tag=!cs:lobby] {"rawtext":[{"text":"${teamCommando}${teamTerrorist}${name} ${killGun} ${teamCommando1}${teamTerrorist1}"},{"selector":"@a[tag=cs:death]"}]}`);
        if (protection === "2") { 
            entity.runCommandAsync(`execute as @s[tag=cs:game,tag=!cs:lobby] at @s run tellraw @s {"rawtext":[{"text":" -300$"},{"text":"§c "},{"translate":"fearcube.cs.teammate_kill_penalty"}]}`);
            entity.runCommandAsync(`scoreboard players remove @s[tag=cs:game,tag=!cs:lobby] cs:balance 300`);
        }
        if (protection === "1") { 
            entity.runCommandAsync(`execute as @s[tag=cs:game,tag=!cs:lobby] at @s run tellraw @s {"rawtext":[{"text":" +${money}$"},{"text":"§2 "},{"translate":"${weapons}"}]}`);
            entity.runCommandAsync(`scoreboard players remove @s[tag=cs:game,tag=!cs:lobby] cs:balance ${money}`);
        }
        entity.runCommandAsync(`tag @a remove "cs:death"`);

    }

    if (event.id === "fearcube:other" && event.message === "cs_select_team") {
        const entity = event.sourceEntity;
        let teamT = getScore("fear_operation", "cs_check_players_terrorist");
        let teamC = getScore("fear_operation", "cs_check_players_commando");
    
        if (teamT < teamC) {entity.runCommandAsync(`tag @s add cs:terrorist`); } 
        else if (teamT > teamC) { entity.runCommandAsync(`tag @s add cs:commando`); } 
        else {entity.runCommandAsync(`tag @s add cs:terrorist`);}
    
        entity.runCommandAsync(`function games/cs/lobby/items`);
        entity.runCommandAsync(`tag @s remove cs:select_team`);
    }
    
    if (event.id === "fearcube:other" && event.message === "cs_title_def_bomb") {
        const entity = event.sourceEntity;

        // sapper kit          
        // no sapper kit         
        let anim1 = "";  let anim2 = ""; let anim3 = ""; let anim4 = ""; let anim5 = ""; let anim6 = ""; let anim7 = "";
    
        if (entity.hasTag("cs:sapper_kit")) { anim1 = ""; anim2 = ""; anim3 = ""; anim4 = ""; anim5 = ""; anim6 = ""; anim7 = ""; }
        else { anim1 = ""; anim2 = ""; anim3 = ""; anim4 = ""; anim5 = ""; anim6 = ""; anim7 = ""; }
    
        entity.runCommandAsync(`execute if entity @e[type=fear:entites_cs_bomb] as @a[tag=cs:commando_bomb_deactivate] at @s if score @s cs:operations matches ..49 run titleraw @s actionbar {"rawtext":[{"text":"${anim1} "},{"translate":"fearcube.cs.bomb_deactivation"}]}`);
        entity.runCommandAsync(`execute if entity @e[type=fear:entites_cs_bomb] as @a[tag=cs:commando_bomb_deactivate] at @s if score @s cs:operations matches 50..74 run titleraw @s actionbar {"rawtext":[{"text":"${anim2} "},{"translate":"fearcube.cs.bomb_deactivation"}]}`);
        entity.runCommandAsync(`execute if entity @e[type=fear:entites_cs_bomb] as @a[tag=cs:commando_bomb_deactivate] at @s if score @s cs:operations matches 75..99 run titleraw @s actionbar {"rawtext":[{"text":"${anim3} "},{"translate":"fearcube.cs.bomb_deactivation"}]}`);
        entity.runCommandAsync(`execute if entity @e[type=fear:entites_cs_bomb] as @a[tag=cs:commando_bomb_deactivate] at @s if score @s cs:operations matches 100..124 run titleraw @s actionbar {"rawtext":[{"text":"${anim4} "},{"translate":"fearcube.cs.bomb_deactivation"}]}`);
        entity.runCommandAsync(`execute if entity @e[type=fear:entites_cs_bomb] as @a[tag=cs:commando_bomb_deactivate] at @s if score @s cs:operations matches 125..149 run titleraw @s actionbar {"rawtext":[{"text":"${anim5} "},{"translate":"fearcube.cs.bomb_deactivation"}]}`);
        entity.runCommandAsync(`execute if entity @e[type=fear:entites_cs_bomb] as @a[tag=cs:commando_bomb_deactivate] at @s if score @s cs:operations matches 150..174 run titleraw @s actionbar {"rawtext":[{"text":"${anim6} "},{"translate":"fearcube.cs.bomb_deactivation"}]}`);
        entity.runCommandAsync(`execute if entity @e[type=fear:entites_cs_bomb] as @a[tag=cs:commando_bomb_deactivate] at @s if score @s cs:operations matches 175..189 run titleraw @s actionbar {"rawtext":[{"text":"${anim7} "},{"translate":"fearcube.cs.bomb_deactivation"}]}`);
        entity.runCommandAsync(`execute if entity @e[type=fear:entites_cs_bomb] as @a[tag=cs:commando_bomb_deactivate] at @s if score @s cs:operations matches 190..200 run titleraw @a[tag=cs:game] actionbar {"rawtext":[{"text":" "},{"translate":"fearcube.cs.bomb_deactivated"}]}`);

    }

    if (event.id === "fearcube:other" && event.message === "cs_players_scroll") {
        const players = world.getPlayers(); 
        let message = "";
    
        players.forEach(player => {
            if (player.hasTag("cs:title.terrorist")) {
                const name = player.name;
    
                const kills = getTagValue(player, "c1");
                const death = getTagValue(player, "c2");
                const moneySpent = getTagValue(player, "c3");
    
                let kills1 = kills >= 0 ? `§a ${kills} ` : '';
                let death1 = death >= 0 ? `§c ${death} ` : '';
                let moneySpent1 = moneySpent > 0 ? `§c-${moneySpent}$ ` : '';
    
                message = `§c${name} ${kills1}${death1}${moneySpent1}\n§9`;
            }


            if (player.hasTag("cs:title.commando")) {
                const name = player.name;
    
                const kills = getTagValue(player, "c1");
                const death = getTagValue(player, "c2");
                const moneySpent = getTagValue(player, "c3");
    
                let kills1 = kills >= 0 ? `§a ${kills} ` : '';
                let death1 = death >= 0 ? `§c ${death} ` : '';
                let moneySpent1 = moneySpent > 0 ? `§c-${moneySpent}$ ` : '';
    
                message = `§9${name} ${kills1}${death1}${moneySpent1}\n§9`;
            }
        });
    
    
           runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"text":" "}]}`);
           runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.game_over"}]}`);

    
            let score = Math.floor(Math.random() * 6);
            let teams = getScore("fear_operation", "cs.winner_i");
            if (teams === 2) {


                if      (score === 0) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_commando"}]}`, true); } 
                else if (score === 1) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_commando1"}]}`, true); } 
                else if (score === 2) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_commando2"}]}`, true); } 
                else if (score === 3) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_commando3"}]}`, true); } 
                else if (score === 4) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_commando4"}]}`, true); } 
                else if (score === 5) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_commando5"}]}`, true); } 
            } 
            else if (teams === 1) {
                if      (score === 0) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_terrorist"}]}`, true); } 
                else if (score === 1) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_terrorist1"}]}`, true); } 
                else if (score === 2) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_terrorist2"}]}`, true); } 
                else if (score === 3) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_terrorist3"}]}`, true); } 
                else if (score === 4) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_terrorist4"}]}`, true); } 
                else if (score === 5) { runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"translate":"fearcube.cs.win_terrorist5"}]}`, true); } 
            } 
           runcmd(`tellraw @a[tag=cs:over_title] {"rawtext":[{"text":"${message}"}]}`, true);
            runcmd(`execute as @a[tag=cs:over_title] at @s run scriptevent fearcube:forms cs_over_stats`);
        
    
        runcmd(`function games/cs/game/stats`);
        runcmd(`tag @a remove cs:stats`);
        
    }
    
    
});