import { world } from "@minecraft/server";

function hasTag(player, tag) {
  return player.getTags().includes(tag);
}

function cleanMessage(message) {
  const unwantedCharacters = ["\\", "\""];
  let cleanedMessage = message;
  for (const char of unwantedCharacters) {
    cleanedMessage = cleanedMessage.split(char).join("");
  }
  return cleanedMessage;
}

async function sendMessageToTaggedPlayers(tag, message) {
  let messageSent = false;
  for (const player of world.getPlayers()) {
    if (hasTag(player, tag)) {
      try {
        await player.runCommandAsync(`tellraw @a[name="${player.name}"] {"rawtext":[{"text":"${message}"}]}`);
        messageSent = true;
      } catch (e) {
        console.error(`Failed to send message to player ${player.name}: ${e}`);
      }
    }
  }
  return messageSent;
}

async function sendMessageToAllPlayers(message) {
  try {
    const players = world.getPlayers();
    if (players.length > 0) {
      await players[0].runCommandAsync(`tellraw @a {"rawtext":[{"text":"${message}"}]}`);
      await players[0].runCommandAsync(`playsound random.pop @a`);
    }
  } catch (e) {
    console.error(`Failed to send message to all players: ${e}`);
  }
}

async function sendPrivateMessage(player, message) {
  try {
    await player.runCommandAsync(`tellraw @a[name="${player.name}"] {"rawtext":[{"text":"${message}"},{"translate":"%fearcube.error2"}]}`);
  } catch (e) {
    console.error(`Failed to send private message to player ${player.name}: ${e}`);
  }
}

function isPlayerFarAway(player) {
  const playerPos = player.location;
  const tagsToCheck = ["lobby", "hns.mobs_lobby", "hns.mobs", "mm:lobby", "mm:game", "cs:terrorist", "cs:commando", "cs:lobby"];
  
  const playerTags = tagsToCheck.filter(tag => player.hasTag(tag));
  
  for (const otherPlayer of world.getPlayers()) {
    if (otherPlayer !== player) {
      const otherPlayerPos = otherPlayer.location;
      const commonTags = playerTags.filter(tag => otherPlayer.hasTag(tag));
      
      if (commonTags.length > 0) {
        const distance = Math.sqrt(
          Math.pow(playerPos.x - otherPlayerPos.x, 2) +
          Math.pow(playerPos.y - otherPlayerPos.y, 2) +
          Math.pow(playerPos.z - otherPlayerPos.z, 2)
        );
        if (distance <= 200) {
          return false;
        }
      }
    }
  }
  return true;
}

async function sendMessageToViverPlayers(message) {
  let messageSent = false;
  for (const player of world.getPlayers()) {
    if (
      hasTag(player, "mm:spectator") || 
      hasTag(player, "hns.mobs:spectator") || 
      hasTag(player, "cs:viewer")
    ) {
      try {
        await player.runCommandAsync(`tellraw @a[name="${player.name}"] {"rawtext":[{"text":"${message}"}]}`);
        messageSent = true;
      } catch (e) {
        console.error(`Failed to send message to player ${player.name}: ${e}`);
      }
    }
  }
  return messageSent;
}

world.beforeEvents.chatSend.subscribe(async (eventData) => {
  const sender = eventData.sender;
  const originalMessage = eventData.message;
  const message = cleanMessage(originalMessage);
  let messageSent = false;
  
  let color = "";
  let smiley = "";
  
  if (hasTag(sender, "nickname:black")) { color = "§0" }
  else if (hasTag(sender, "nickname:dark_blue")) { color = "§1" }
  else if (hasTag(sender, "nickname:dark_green")) { color = "§2" }
  else if (hasTag(sender, "nickname:dark_aqua")) { color = "§3" }
  else if (hasTag(sender, "nickname:dark_red")) { color = "§4" }
  else if (hasTag(sender, "nickname:dark_purple")) { color = "§5" }
  else if (hasTag(sender, "nickname:gold")) { color = "§6" }
  else if (hasTag(sender, "nickname:gray")) { color = "§7" }
  else if (hasTag(sender, "nickname:dark_gray")) { color = "§8" }
  else if (hasTag(sender, "nickname:blue")) { color = "§9" }
  else if (hasTag(sender, "nickname:green")) { color = "§a" }
  else if (hasTag(sender, "nickname:aqua")) { color = "§b" }
  else if (hasTag(sender, "nickname:red")) { color = "§c" }
  else if (hasTag(sender, "nickname:light_purple")) { color = "§d" }
  else if (hasTag(sender, "nickname:yellow")) { color = "§e" }
  else if (hasTag(sender, "nickname:white")) { color = "§f" }
  
  if (hasTag(sender, "smiley:1")) { smiley = " " }
  else if (hasTag(sender, "smiley:2")) { smiley = " " }
  else if (hasTag(sender, "smiley:3")) { smiley = " " }
  else if (hasTag(sender, "smiley:4")) { smiley = " " }
  else if (hasTag(sender, "smiley:5")) { smiley = " " }
  else if (hasTag(sender, "smiley:6")) { smiley = " " }
  else if (hasTag(sender, "smiley:7")) { smiley = " " }
  else if (hasTag(sender, "smiley:8")) { smiley = " " }
  else if (hasTag(sender, "smiley:9")) { smiley = " " }
  else if (hasTag(sender, "smiley:10")) { smiley = " " }
  else if (hasTag(sender, "smiley:11")) { smiley = " " }
  else if (hasTag(sender, "smiley:12")) { smiley = " " }
  else if (hasTag(sender, "smiley:13")) { smiley = " " }
  else if (hasTag(sender, "smiley:14")) { smiley = " " }
  else if (hasTag(sender, "smiley:15")) { smiley = " " }
  else if (hasTag(sender, "smiley:16")) { smiley = " " }
  else if (hasTag(sender, "smiley:17")) { smiley = " " }
  else if (hasTag(sender, "smiley:18")) { smiley = " " }
  else if (hasTag(sender, "smiley:19")) { smiley = " " }
  
  let coloredName = sender.name; 
  if (hasTag(sender, "lobby") || hasTag(sender, "hns.mobs_lobby") || hasTag(sender, "mm:lobby") || hasTag(sender, "cs:lobby")) {
      coloredName = `${smiley}${color}${sender.name}§r`; 
  }
  
  

  if (originalMessage.startsWith('\\')) {
    switch (originalMessage) {
      case '\\hub':
        eventData.cancel = true;
        sender.runCommandAsync('function games/link_to_lobby');
        return;
      case '\\lobby':
        eventData.cancel = true;
        sender.runCommandAsync('function games/link_to_lobby');
        return;
      case '\\help':
        eventData.cancel = true;
        sender.runCommandAsync('function commands/command');
        return;
      case '\\music off':
        eventData.cancel = true;
        sender.runCommandAsync('function commands/music_off');
        return;
      case '\\music on':
        eventData.cancel = true;
        sender.runCommandAsync('function commands/music_on');
        return;
      case '\\music next':
        eventData.cancel = true;
        sender.runCommandAsync('function commands/music_next');
        return;
      default:
        break;
    }
  }

  if (
    hasTag(sender, "lobby") || 
    hasTag(sender, "hns.mobs_lobby") || 
    hasTag(sender, "hns.mobs") ||
    hasTag(sender, "mm:lobby") ||
    hasTag(sender, "mm:game") ||
    hasTag(sender, "cs:terrorist") ||
    hasTag(sender, "cs:commando") ||
    hasTag(sender, "cs:viewer") ||
    hasTag(sender, "cs:lobby")
  ) {
    if (message.startsWith("!")) {
      if (
        !hasTag(sender, "mm:spectator") && 
        !hasTag(sender, "hns.mobs:spectator") && 
        !hasTag(sender, "cs:viewer")
      ) {
        const broadcastMessage = message.substring(1).trim();
        eventData.cancel = true;
        await sendMessageToAllPlayers(`${coloredName}  ${broadcastMessage}`);
        messageSent = true;
      } else {
        eventData.cancel = true;
      }
    } else {
      eventData.cancel = true;
      
      if (hasTag(sender, "lobby")) {
        messageSent = await sendMessageToTaggedPlayers("lobby", `${coloredName}  ${message}`);
      } else if (hasTag(sender, "hns.mobs_lobby")) {
        messageSent = await sendMessageToTaggedPlayers("hns.mobs_lobby", `${coloredName}  ${message}`);
      } else if (hasTag(sender, "mm:lobby")) {
        messageSent = await sendMessageToTaggedPlayers("mm:lobby", `${coloredName}  ${message}`);
      } else if (hasTag(sender, "cs:lobby")) {
        messageSent = await sendMessageToTaggedPlayers("cs:lobby", `${coloredName}  ${message}`);
      } else if (hasTag(sender, "cs:viewer")) {
        messageSent = await sendMessageToTaggedPlayers("cs:viewer", `${coloredName}  ${message}`);
      }
      
      if (!hasTag(sender, "cs:lobby")) {
        if (hasTag(sender, "cs:commando")) {
          if (hasTag(sender, "cs:viewer")) {
            messageSent = await sendMessageToViverPlayers(`${coloredName}  ${message}`);
          } else {
            messageSent = await sendMessageToTaggedPlayers("cs:commando", `§9${coloredName} team >§r ${message}`, true);
          }
        }
      }

      if (!hasTag(sender, "cs:lobby")) {
        if (hasTag(sender, "cs:terrorist")) {
          if (hasTag(sender, "cs:viewer")) {
            messageSent = await sendMessageToViverPlayers(`${coloredName}  ${message}`);
          } else {
            messageSent = await sendMessageToTaggedPlayers("cs:terrorist", `§c${coloredName} team >§r ${message}`, true);
          }
        }
      }

      if (hasTag(sender, "hns.mobs")) {
        if (hasTag(sender, "hns.mobs:spectator")) {
          messageSent = await sendMessageToViverPlayers(`${coloredName}  ${message}`);
        } else {
          messageSent = await sendMessageToTaggedPlayers("hns.mobs", `${coloredName}  ${message}`, true);
        }
      }

      if (hasTag(sender, "mm:game")) {
        if (hasTag(sender, "mm:spectator")) {
          messageSent = await sendMessageToViverPlayers(`${coloredName}  ${message}`);
        } else {
          messageSent = await sendMessageToTaggedPlayers("mm:game", `${coloredName}  ${message}`, true);
        }
      }

      if (isPlayerFarAway(sender)) {
        await sendPrivateMessage(sender, "§c");
      }
    }

    if (!messageSent) {
      try {
        await sender.runCommandAsync(`playsound random.pop @a[name="${sender.name}"]`);
      } catch (e) {
        console.error(`Failed to play sound for sender ${sender.name}: ${e}`);
      }
    }
  }
});
