import { ActionFormData } from "@minecraft/server-ui";
import { system, world } from '@minecraft/server';
import { SubjectSelectionNickname, SubjectShutdownNickname } from '../other/shoops/nickname.js';
import { SubjectSelectionHats, SubjectShutdownHats } from '../other/shoops/custom_cloth.js';
import { SubjectSelectionSmiley, SubjectShutdownSmiley } from '../other/shoops/smiley.js';
import { inventoryItems } from './inventoryItems.js'; 

system.afterEvents.scriptEventReceive.subscribe((event) => {
    if (event.id === "fearcube:forms" && event.message === "inventoryMain") {

        let player = event.sourceEntity;
        let name = event.sourceEntity.name;

        let form = new ActionFormData();
        form.title(" Inventory");
        form.body(``);

        let index = 0;
        let options = [];
        let hasItems = false;  

        
        inventoryItems.forEach(item => {
            if (player.hasTag(item.trueTag)) {  
                let buttonLabel;
                if (player.hasTag(item.tag)) {
                    buttonLabel = "%fearcube.used";  
                } else {
                    buttonLabel = "%fearcube.choose";  
                }

                form.button(buttonLabel, item.texture);
                options.push({ itemTag: item.tag, type: item.type, items: item.items, index: index++ });
                hasItems = true;  
            }
        });

        
        if (!hasItems) {
            form.button("%joincode.icon_text.null", "textures/blocks/web");
        }

        form.show(player).then(r => {
            if (r.canceled) return;

            
            if (!hasItems) {
                return;
            }

            let response = r.selection;
            let selectedItem = options.find(option => option.index === response);
            let itemID = parseInt(selectedItem.items);

            if (selectedItem) {
                // Если предмет надет, снимаем его
                if (player.hasTag(selectedItem.itemTag)) {
                    switch (selectedItem.type) {
                        case 'hat':
                            SubjectShutdownHats(player, name);
                            break;
                        case 'nickname':
                            SubjectShutdownNickname(player, name);
                            break;
                        case 'smiley':
                            SubjectShutdownSmiley(player, name);
                            break;
                        default:
                            player.runCommandAsync(`say Неизвестный тип: ${selectedItem.type}`);
                    }
                } else {  
                    switch (selectedItem.type) {
                        case 'hat':
                            SubjectSelectionHats(player, itemID, name);
                            break;
                        case 'nickname':
                            SubjectSelectionNickname(player, itemID, name);
                            break;
                        case 'smiley':
                            SubjectSelectionSmiley(player, itemID, name);
                            break;
                        default:
                            player.runCommandAsync(`say Неизвестный тип: ${selectedItem.type}`);
                    }
                }
            }
        }).catch(e => {
            console.error(e, e.stack);
        });
        
    }
});
