import { system, world, Player } from '@minecraft/server';
import { getPlayerTagData, getTagValue } from '../systemFiles/tagUtils';

const originalNicknames = new Map();

function setTickTimeout(callback, tick) {
    const id = system.runInterval(() => {
      callback();
      system.clearRun(id);
    }, tick);
}

function getOriginalNickname(player) {
    const tags = player.getTags();
    const originalNickTag = tags.find(tag => tag.startsWith("originalNick:"));
    return originalNickTag ? originalNickTag.replace("originalNick:", "") : player.name;
}

function saveOriginalNickname(player) {
    if (!originalNicknames.has(player.name)) {
        originalNicknames.set(player.name, player.nameTag);
        player.addTag(`originalNick:${player.nameTag}`);
        console.log(`Saved original nickname for player: ${player.name}`);
    }
}

function setInvisibleNickname(player) {
    player.nameTag = "§7"; 
    console.log(`Set invisible nickname for player: ${player.name}`);
}

function restoreOriginalNickname(player) {
    const originalNickname = getOriginalNickname(player);
    player.nameTag = originalNickname;
    originalNicknames.delete(player.name);
    console.log(`Restored original nickname for player: ${player.name}`);
}

function setRedNickname(player) {
    saveOriginalNickname(player);
    const originalNickname = getOriginalNickname(player);
    player.nameTag = "§c" + originalNickname; // Красный цвет
    console.log(`Set red nickname for player: ${player.name}`);
}

function setBlueNickname(player) {
    saveOriginalNickname(player);
    const originalNickname = getOriginalNickname(player);
    player.nameTag = "§9" + originalNickname; // Синий цвет
    console.log(`Set blue nickname for player: ${player.name}`);
}

const colorTags = {
    "nickname:black": "§0", "nickname:dark_blue": "§1", "nickname:dark_green": "§2",
    "nickname:dark_aqua": "§3", "nickname:dark_red": "§4", "nickname:dark_purple": "§5",
    "nickname:gold": "§6", "nickname:gray": "§7", "nickname:dark_gray": "§8",
    "nickname:blue": "§9", "nickname:green": "§a", "nickname:aqua": "§b",
    "nickname:red": "§c", "nickname:light_purple": "§d", "nickname:yellow": "§e",
    "nickname:white": "§f"
};

const smileyTags = {
    "smiley:1": "", "smiley:2": "", "smiley:3": "", "smiley:4": "",
    "smiley:5": "", "smiley:6": "", "smiley:7": "", "smiley:8": "",
    "smiley:9": "", "smiley:10": "", "smiley:11": "", "smiley:12": "",
    "smiley:13": "", "smiley:14": "", "smiley:15": "", "smiley:16": "",
    "smiley:17": "", "smiley:18": "", "smiley:19": ""
};

async function setLobbyNickname(player) {
    saveOriginalNickname(player);
    const originalNickname = getOriginalNickname(player);

    let color = Object.keys(colorTags).find(tag => player.hasTag(tag)) || "";
    let smiley = Object.keys(smileyTags).find(tag => player.hasTag(tag)) || "";
    
    const score = await getTagValue(player, "lvl");
    const displayColor = colorTags[color] || "§7";
    const displaySmiley = smileyTags[smiley] || "";

    player.nameTag = `§7${score} |${displaySmiley} ${displayColor}${originalNickname}`;
}

world.afterEvents.playerJoin.subscribe(event => {
    setTickTimeout(() => {
        const playerName = event.playerName;
        const player = world.getPlayers().find(p => p.name === playerName);
        if (player) {
            saveOriginalNickname(player);
        }
    }, 150);
});

system.afterEvents.scriptEventReceive.subscribe((event) => {
    const { id, sourceEntity, message } = event;

    if (!sourceEntity || typeof sourceEntity.name !== "string") return;

    const player = world.getPlayers().find(p => p.name === sourceEntity.name);
    if (!player) return;

    if (id === "fearcube:nickname" && message === "off") {
        setInvisibleNickname(player);
    } else if (id === "fearcube:nickname" && message === "on") {
        restoreOriginalNickname(player);
    } else if (id === "fearcube:nickname" && message === "red") {
        setRedNickname(player);
    } else if (id === "fearcube:nickname" && message === "blue") {
        setBlueNickname(player);
    } else if (id === "fearcube:nickname" && message === "lobby") {
        setLobbyNickname(player);
    }
});

export { setLobbyNickname };


