import { Player, system } from '@minecraft/server';

const tagKey = "PlayerTag";

function getTagData(tag) {
    try {
        return JSON.parse(tag);
    } catch (e) {
        return {};
    }
}

function setTagData(data) {
    return JSON.stringify(data);
}

function getPlayerTagData(player) {
    const currentTag = player.getTags().find(tag => tag.startsWith(tagKey));
    if (currentTag) {
        return getTagData(currentTag.replace(`${tagKey}=`, ''));
    }
    return {};
}

function getTagValue(player, key) {
    const tagData = getPlayerTagData(player);
    return tagData[key] !== undefined ? tagData[key] : null;
}

function updateTagData(player, key, value, isAddition = true) {
    let tagData = {};
    const currentTag = player.getTags().find(tag => tag.startsWith(tagKey));

    if (currentTag) {
        tagData = getTagData(currentTag.replace(`${tagKey}=`, ''));
    }

    if (value === null) {
        delete tagData[key];
    } else {
        if (isAddition) {
            tagData[key] = (tagData[key] || 0) + value;
        } else {
            tagData[key] = (tagData[key] || 0) - value;
            if (tagData[key] <= 0) {
                delete tagData[key];
            }
        }
    }

    if (currentTag) {
        player.removeTag(currentTag);
    }
    player.addTag(`${tagKey}=${setTagData(tagData)}`);
}



// системные настройки
system.afterEvents.scriptEventReceive.subscribe((event) => {
    const player = event.sourceEntity;

    if (player instanceof Player) {
        if (event.id === "fearcube:add_tag") {
            const [key, value] = event.message.split('=');
            updateTagData(player, key, parseInt(value), true);
        }

        if (event.id === "fearcube:remove_tag") {
            const [key, value] = event.message.split('=');
            updateTagData(player, key, parseInt(value), false);
        }

        if (event.id === "fearcube:list_tag") {
            const currentTag = player.getTags().find(tag => tag.startsWith("PlayerTag"));
            if (currentTag) {
                const tagData = getTagData(currentTag.replace("PlayerTag=", ''));
                player.sendMessage(`Your tags: ${JSON.stringify(tagData)}`);
            } else {
                player.sendMessage("You have no tags.");
            }
        }

        if (event.id === "fearcube:reset_tag") {
            const key = event.message;
            updateTagData(player, key, null);
        }
    }
});

export { getPlayerTagData, getTagValue, updateTagData };
